@@ -29,12 +29,12 @@ if __name__ == "__main__":
     print('Drive Info: {}'.format(con.get_drive_info()))
     print('Current Folder {Path} Free Space: {Free Size} Attrib: {Dir_Attributs}'.format(**con.get_directory_info()))
 
-    print('PLC Marker: {}'.format(con.read_plc_memory(address=0, mem_type=pyLSV2.PLC_MEM_TYPE_MARKER, count=15)))
-    print('PLC Word: {}'.format(con.read_plc_memory(address=6, mem_type=pyLSV2.PLC_MEM_TYPE_WORD, count=10)))
-    print('PLC Double Word: {}'.format(con.read_plc_memory(address=0, mem_type=pyLSV2.PLC_MEM_TYPE_DWORD, count=10)))
-    print('PLC String: {}'.format(con.read_plc_memory(address=2, mem_type=pyLSV2.PLC_MEM_TYPE_STRING, count=2)))
-    print('PLC Input: {}'.format(con.read_plc_memory(address=0, mem_type=pyLSV2.PLC_MEM_TYPE_INPUT, count=5)))
-    print('PLC Word Output: {}'.format(con.read_plc_memory(address=10, mem_type=pyLSV2.PLC_MEM_TYPE_OUTPUT_WORD, count=5)))
+    print('PLC Marker: {}'.format(con.read_plc_memory(address=0, mem_type=pyLSV2.MemoryType.MARKER, count=15)))
+    print('PLC Word: {}'.format(con.read_plc_memory(address=6, mem_type=pyLSV2.MemoryType.WORD, count=10)))
+    print('PLC Double Word: {}'.format(con.read_plc_memory(address=0, mem_type=pyLSV2.MemoryType.DWORD, count=10)))
+    print('PLC String: {}'.format(con.read_plc_memory(address=2, mem_type=pyLSV2.MemoryType.STRING, count=2)))
+    print('PLC Input: {}'.format(con.read_plc_memory(address=0, mem_type=pyLSV2.MemoryType.INPUT, count=5)))
+    print('PLC Word Output: {}'.format(con.read_plc_memory(address=10, mem_type=pyLSV2.MemoryType.OUTPUT_WORD, count=5)))
 
     # reading of machine parameter for old an new style names
     if not con.is_itnc():
@@ -45,22 +45,22 @@ if __name__ == "__main__":
         print('Current Language: {}'.format(con.get_machine_parameter('7230.0')))
 
     # changing the value of a machine parameter
-    # con.login(pyLSV2.LOGIN_PLCDEBUG)
+    # con.login(pyLSV2.Login.PLCDEBUG)
     # new style: con.set_machine_parameter('CfgDisplayLanguage.ncLanguage', 'CZECH', safe_to_disk=False)
     # old style: con.set_machine_parameter('7230.0', '2', safe_to_disk=False)
-    # con.logout(pyLSV2.LOGIN_PLCDEBUG)
+    # con.logout(pyLSV2.Login.PLCDEBUG)
 
     # read program stack
     print('Current Program Stack: {}'.format(con.get_program_stack()))
 
     # demo for sending key codes
-    con.login(pyLSV2.LOGIN_MONITOR)
+    con.login(pyLSV2.Login.MONITOR)
     con.set_keyboard_access(False)
-    con.send_key_code(pyLSV2.KEY_MODE_MANUAL)
+    con.send_key_code(pyLSV2.KeyCode.MODE_MANUAL)
     time.sleep(3)
-    con.send_key_code(pyLSV2.KEY_MODE_PGM_EDIT)
+    con.send_key_code(pyLSV2.KeyCode.MODE_PGM_EDIT)
     con.set_keyboard_access(True)
-    con.logout(pyLSV2.LOGIN_MONITOR)
+    con.logout(pyLSV2.Login.MONITOR)
 
     # demo for reading the current tool with fallback if it is not supported by control
     t_info = con.get_spindle_tool_status()
@@ -100,8 +100,8 @@ if __name__ == "__main__":
 
     # list all NC-Programms in TNC partition
     h_files = con.get_file_list(path='TNC:', pattern=r'[\$A-Za-z0-9_-]*\.[hH]$')
-    print('Found {:d} Klartext programms: {:}'.format(len(h_files), h_files))
+    print('Found {:d} Klartext programs: {:}'.format(len(h_files), h_files))
     i_files = con.get_file_list(path='TNC:', pattern=r'[\$A-Za-z0-9_-]*\.[iI]$')
-    print('Found {:d} DIN/ISO programms: {:}'.format(len(i_files), i_files))
+    print('Found {:d} DIN/ISO programs: {:}'.format(len(i_files), i_files))
 
     con.disconnect()
